<?php

namespace Drupal\doccheck_basic\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\doccheck_basic\DoccheckBasicCommon;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides a 'doccheck_basic' block.
 *
 * @Block(
 *   id = "doccheck_basic",
 *   admin_label = @Translation("DocCheck Basic"),
 *   category = @Translation("Login")
 * )
 */
class FormBlock extends BlockBase implements ContainerFactoryPluginInterface {
  /**
   * The variable containing the logging.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactory
   */
  private $logger;

  /**
   * The variable containing the conditions configuration.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private $config;

  /**
   * The variable containing the current user.
   *
   * @var AccountProxy
   */
  protected $currentUser;

  /**
   * The variable containing the request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The variable containing the language manager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * The variable containing the killswitch service.
   *
   * @var \Drupal\Core\PageCache\ResponsePolicy\KillSwitch
   */
  protected $killSwitch;

  /**
   * The redirect destination service.
   *
   * @var \Drupal\Core\Routing\RedirectDestinationInterface
   */
  protected $redirectDestination;

  /**
   * Dependency injection through the constructor.
   *
   * @param array $configuration
   *   The block configuration.
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger
   *   The logger service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config
   *   The config service.
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   *   The current user service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   *   The request stack service.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The language service.
   * @param \Drupal\Core\PageCache\ResponsePolicy\KillSwitch $killSwitch
   *   The killswitch service.
   * @param \Drupal\Core\Routing\RedirectDestinationInterface $redirect_destination
   *   The redirect destination service.
   */
  public function __construct(array $configuration,
  $plugin_id,
  $plugin_definition,
  LoggerChannelFactoryInterface $logger,
  ConfigFactoryInterface $config,
  AccountProxyInterface $currentUser,
  RequestStack $requestStack,
  LanguageManager $languageManager,
  KillSwitch $killSwitch,
  RedirectDestinationInterface $redirect_destination
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->logger = $logger;
    $this->config = $config->get('config.doccheck_basic');
    $this->currentUser = $currentUser;
    $this->requestStack = $requestStack->getCurrentRequest();
    $this->languageManager = $languageManager;
    $this->killSwitch = $killSwitch;
    $this->redirectDestination = $redirect_destination;
  }

  /**
   * Dependency injection create.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static($configuration,
    $plugin_id,
    $plugin_definition,
    $container->get('logger.factory'),
    $container->get('config.factory'),
    $container->get('current_user'),
    $container->get('request_stack'),
    $container->get('language_manager'),
    $container->get('page_cache_kill_switch'),
    $container->get('redirect.destination')
    );
  }

  /**
   * Doccheck login block.
   */
  public function build() {
    $docCheckBasicCommon = new DoccheckBasicCommon($this->logger, $this->config, $this->currentUser, $this->requestStack, $this->languageManager, $this->redirectDestination);
    return $docCheckBasicCommon->doccheckBasicLogin('block');

  }

  /**
   * No caching for login block.
   */
  public function getCacheMaxAge() {
    $this->killSwitch->trigger();
    return 0;
  }

}
